==> xl-react-components-0.16.62.tgz: package/tests/unit/xl-react-widget/xl-react-widget-redux-table/saga/xl-react-widget-redux-table-common-saga-spec.js <==
import R from 'ramda';
import {delay} from 'redux-saga';
import {testSaga} from 'redux-saga-test-plan';
import {
    fetchData,
    initializeSaga,
    refreshSaga,
    withDelay,
    withSpinner
} from '~/app/xl-react-widget/xl-react-widget-redux-table/sagas/xl-react-widget-redux-table-common-saga';
import tableActions from '~/app/xl-react-widget/xl-react-widget-redux-table/xl-react-widget-redux-table-actions';
import {getTableById} from '~/app/xl-react-widget/xl-react-widget-redux-table/xl-react-widget-table-selectors';
import {paginateSaga} from '~/app/xl-react-widget/xl-react-widget-redux-table/sagas/xl-react-widget-redux-table-pagination-saga'; // eslint-disable-line max-len
import {extractTotal} from '~/app/utils/http-utils';
import {call} from 'redux-saga/effects';

describe('Widget Redux Table Common Saga', () => {
    describe('fetchData', () => {
        const tableId = 'table-1';
        const mockApi = jest.fn();
        const filters = [{
            fieldPath: 'firstname',
            model: 'Bogdan'
        }, {
            fieldPath: 'address',
            model: 'Haarlem'
        }];
        const paging = {page: 1};
        const sorting = {name: 'completionDate', order: 'desc'};
        const data = [];
        const headers = {'x-total-count': data.length};
        const layout = [{dataKey: 'completionDate', sortKey: 'completionDate'}];

        it('should fetch data by provided api function and for a certain table', () => {
            const saga = testSaga(fetchData, tableId, mockApi);
            saga.next().select(getTableById, tableId);
            saga.next({filters, layout, paging, sorting}).call(mockApi, {
                address: 'Haarlem',
                firstname: 'Bogdan'
            }, paging, sorting);
            saga.next({data, headers}).put(tableActions.show({data, tableId, total: extractTotal(headers)}));
            saga.next().isDone();
        });

        it('should show error to the user if any error occurred during fetching the data', () => {
            const error = 'error';
            const saga = testSaga(fetchData, tableId, mockApi);
            saga.next().select(getTableById, tableId);
            saga.next({filters, layout, paging, sorting}).call(mockApi, {
                address: 'Haarlem',
                firstname: 'Bogdan'
            }, paging, sorting);
            saga.throw(error).put(tableActions.show({error, tableId}));
            saga.next().isDone();
        });
    });

    describe('withDelay', () => {
        it('should call any effect with a certain delay', () => {
            const saga = testSaga(withDelay, call(R.F), 100);
            saga.next().call(delay, 100);
            saga.next().call(R.F);
            saga.next().isDone();
        });
    });

    describe('withSpinner', () => {
        it('should reflect in redux store when the spinner has to be displayed while an action is in progress', () => {
            const tableId = 'table-1';
            const saga = testSaga(withSpinner, tableId, call(R.F));
            saga.next().put(tableActions.changeLoadingState(tableId, true));
            saga.next().call(R.F);
            saga.next().put(tableActions.changeLoadingState(tableId, false));
            saga.next().isDone();
        });

        it('should reflect in redux store when the spinner has to be displayed' +
            ' if during the executing of action an exception has occurred', () => {
            const tableId = 'table-1';
            const saga = testSaga(withSpinner, tableId, call(R.F));
            saga.next().put(tableActions.changeLoadingState(tableId, true));
            saga.next().call(R.F);
            saga.throw('error').put(tableActions.changeLoadingState(tableId, false));
            saga.next().isDone();
        });
    });

    describe('refreshSaga', () => {
        it('should refresh fetched data', () => {
            const resultsPerPage = 10;
            const tableId = 'table-1';
            const mockApi = jest.fn();
            const saga = testSaga(refreshSaga, {api: mockApi, tableId});
            saga.next().select(getTableById, tableId);
            saga.next({paging: {resultsPerPage}}).call(paginateSaga, {api: mockApi, page: 1, resultsPerPage, tableId});
            saga.next().isDone();
        });
    });

    describe('initializeSaga', () => {
        it('should populate table with initial data', () => {
            const mockApi = jest.fn();
            const action = {api: mockApi, tableId: 'my-table'};
            const saga = testSaga(initializeSaga, action);
            saga.next().call(withSpinner, action.tableId, call(fetchData, action.tableId, action.api));
            saga.next().isDone();
        });
    });
});

==> xl-react-components-0.21.15.tgz: package/tests/unit/xl-react-widget/xl-react-widget-redux-table/saga/xl-react-widget-redux-table-common-saga-spec.js <==
import R from 'ramda';
import {testSaga} from 'redux-saga-test-plan';
import {call} from 'redux-saga/effects';
import {
    fetchData,
    initializeSaga,
    refreshSaga,
    withDelay,
    withSpinner
} from '~/app/xl-react-widget/xl-react-widget-redux-table/sagas/xl-react-widget-redux-table-common-saga';
import tableActions from '~/app/xl-react-widget/xl-react-widget-redux-table/xl-react-widget-redux-table-actions';
import {
    getTableById,
    getSortingWithSortKey
} from '~/app/xl-react-widget/xl-react-widget-redux-table/xl-react-widget-table-selectors';
import {paginateSaga} from '~/app/xl-react-widget/xl-react-widget-redux-table/sagas/xl-react-widget-redux-table-pagination-saga'; // eslint-disable-line max-len
import {extractTotal} from '~/app/utils/http-utils';

describe('Widget Redux Table Common Saga', () => {
    describe('fetchData', () => {
        const tableId = 'table-1';
        const mockApi = jest.fn();
        const filters = [{
            fieldPath: 'firstname',
            model: 'Bogdan'
        }, {
            fieldPath: 'address',
            model: 'Haarlem'
        }];
        const paging = {page: 1};
        const sorting = {name: 'completionDate', order: 'desc'};
        const data = [];
        const headers = {'x-total-count': data.length};
        const metaData = {change: {previous: {}, type: 'filter'}};

        it('should fetch data by provided api function and for a certain table', () => {
            const saga = testSaga(fetchData, tableId, mockApi, metaData);
            saga.next().select(getTableById, tableId);
            saga.next({filters, paging}).select(getSortingWithSortKey, tableId);
            saga.next(sorting).call(mockApi, {
                address: 'Haarlem',
                firstname: 'Bogdan'
            }, paging, sorting, metaData);
            saga.next({data, headers}).put(tableActions.show({data, tableId, total: extractTotal(headers)}));
            saga.next().isDone();
        });

        it('should show error to the user if any error occurred during fetching the data', () => {
            const error = 'error';
            const saga = testSaga(fetchData, tableId, mockApi, metaData);
            saga.next().select(getTableById, tableId);
            saga.next({filters, paging}).select(getSortingWithSortKey, tableId);
            saga.next(sorting).call(mockApi, {
                address: 'Haarlem',
                firstname: 'Bogdan'
            }, paging, sorting, metaData);
            saga.throw(error).put(tableActions.show({error, tableId}));
            saga.next().isDone();
        });
    });

    describe('withDelay', () => {
        it('should call any effect with a certain delay', () => {
            const saga = testSaga(withDelay, call(R.F), 100);
            saga.next().delay(100);
            saga.next().call(R.F);
            saga.next().isDone();
        });
    });

    describe('withSpinner', () => {
        it('should reflect in redux store when the spinner has to be displayed while an action is in progress', () => {
            const tableId = 'table-1';
            const saga = testSaga(withSpinner, tableId, call(R.F));
            saga.next().put(tableActions.changeLoadingState(tableId, true));
            saga.next().call(R.F);
            saga.next().put(tableActions.changeLoadingState(tableId, false));
            saga.next().isDone();
        });

        it('should reflect in redux store when the spinner has to be displayed' +
            ' if during the executing of action an exception has occurred', () => {
            const tableId = 'table-1';
            const saga = testSaga(withSpinner, tableId, call(R.F));
            saga.next().put(tableActions.changeLoadingState(tableId, true));
            saga.next().call(R.F);
            saga.throw('error').put(tableActions.changeLoadingState(tableId, false));
            saga.next().isDone();
        });
    });

    describe('refreshSaga', () => {
        it('should refresh fetched data', () => {
            const resultsPerPage = 10;
            const tableId = 'table-1';
            const mockApi = jest.fn();
            const saga = testSaga(refreshSaga, {api: mockApi, tableId});
            saga.next().select(getTableById, tableId);
            saga.next({paging: {resultsPerPage}}).call(paginateSaga, {api: mockApi, page: 1, resultsPerPage, tableId});
            saga.next().isDone();
        });
    });

    describe('initializeSaga', () => {
        it('should populate table with initial data', () => {
            const mockApi = jest.fn();
            const action = {api: mockApi, tableId: 'my-table'};
            const saga = testSaga(initializeSaga, action);
            saga.next().call(withSpinner, action.tableId, call(fetchData, action.tableId, action.api));
            saga.next().isDone();
        });
    });
});
